using System.Windows.Forms;

namespace InfragisticsDockableTestApplication
{
	/// <summary>
	/// Implement a SplitContainer with panel-dock, panel-move, panel-resize capabilities
	/// </summary>
	public partial class SplitContainerDockable :UserControl// SplitContainer
	{
		#region private
		private Infragistics.Win.UltraWinDock.DockableWindow dockableWindow;
		private Panel _panel1;
		private Panel _panel2;
		private Control _control1;
		private Control _control2;
		#endregion
		/// <summary>
		/// Default constructor
		/// </summary>
		public SplitContainerDockable()
		{
			InitializeComponent();

			this.ultraDockManager.DefaultPaneSettings.AllowClose = Infragistics.Win.DefaultableBoolean.False;

			// 
			// dockableWindow3
			// 
			this.dockableWindow = new Infragistics.Win.UltraWinDock.DockableWindow();
			dockableWindow.SuspendLayout();

			//dockableWindow.Controls.Add(c);
			dockableWindow.Name = "dockableWindow";
			dockableWindow.Owner = this.ultraDockManager;

			dockableWindow.ResumeLayout(false);
			this._panel1 = new Panel();
			this._panel2 = new Panel();
			this.AddControl(this._panel1, "1", "Panel 1");
			this.AddControl(this._panel2, "2", "Panel 2");

			this.Orientation = Orientation.Horizontal;

			this.Panel1Control = null;
			this.Panel2Control = null;
		}

        ///// <summary>
        ///// Get or set a value specifying the window appearence for rendering the control 
        ///// </summary>
        //public override Ors.Controls.WinForms.WindowStyle WindowStyle
        //{
        //    get
        //    {
        //        return (Ors.Controls.WinForms.WindowStyle)(this.ultraDockManager.WindowStyle);
        //    }
        //    set
        //    {
        //        this.ultraDockManager.WindowStyle = (Infragistics.Win.UltraWinDock.WindowStyle)value;
        //    }
        //}

		/// <summary>
		/// Add a control
		/// </summary>
		/// <param name="control">The control to be added</param>
		/// <param name="key">The key that identifies the control</param>
		/// <param name="description">A description for the control</param>
		private void AddControl(Control control, string key, string description)
		{
			Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane;

			if (this.ultraDockManager.DockAreas.Count == 0)
			{
				dockAreaPane = new Infragistics.Win.UltraWinDock.DockAreaPane(Infragistics.Win.UltraWinDock.DockedLocation.DockedLeft);
				dockAreaPane.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
				this.ultraDockManager.DockAreas.AddRange(new Infragistics.Win.UltraWinDock.DockAreaPane[] { dockAreaPane });
			}
			else
			{
				dockAreaPane = this.ultraDockManager.DockAreas[0];
			}


			control.Dock = DockStyle.Fill;

			Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane = new Infragistics.Win.UltraWinDock.DockableControlPane(key, description, control);

			dockableControlPane.Control = control;
			dockableControlPane.Text = description;

			dockAreaPane.Panes.Add(dockableControlPane);

			this.ultraDockManager.DockAreas[0].SelectedTabIndex = this.ultraDockManager.DockAreas[0].Panes.Count;
		}


		/// <summary>
		/// Get or set a value indicating the orientation of the splitter
		/// </summary>
		public Orientation Orientation
		{
			get
			{
				if (this.ultraDockManager.DockAreas[0].DockAreaPane.ChildPaneStyle == Infragistics.Win.UltraWinDock.ChildPaneStyle.HorizontalSplit)
				{
					return Orientation.Horizontal;
				}
				else
				{
					return Orientation.Vertical;
				}
			}
			set
			{
				Orientation o = value;
				if (o == Orientation.Horizontal)
				{
					this.ultraDockManager.DockAreas[0].DockAreaPane.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.HorizontalSplit;
				}
				else
				{
					this.ultraDockManager.DockAreas[0].DockAreaPane.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.VerticalSplit;
				}
			}
		}


		private Infragistics.Win.UltraWinDock.DockableControlPane GetPane(string key)
		{
			Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane = this.ultraDockManager.DockAreas[0];
			Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane = dockAreaPane.Panes[key] as Infragistics.Win.UltraWinDock.DockableControlPane;

			return dockableControlPane;
		}


		/// <summary>
		/// Get or set the description for panel 1
		/// </summary>
		public string Panel1Description
		{
			get
			{
				return this.GetPane("1").Text;
			}
			set
			{
				this.GetPane("1").Text = value;
			}
		}

		/// <summary>
		/// Get or set the description for panel 2
		/// </summary>
		public string Panel2Description
		{
			get
			{
				return this.GetPane("2").Text;
			}
			set
			{
				this.GetPane("2").Text = value;
			}
		}

		/// <summary>
		/// Get or set the control for panel 1
		/// </summary>
		public Control Panel1Control
		{
			get
			{
				//return this.GetPane("1").Control;
				return this._control1;
			}
			set
			{
				this._control1 = value;

				Control control = this._control1;
				this._panel1.Controls.Clear();
				if (control != null)
				{
					control.Dock = DockStyle.Fill;
					this._panel1.Controls.Add(control);
				}
				//this.GetPane("2").Control = control;
			}
		}

		/// <summary>
		/// Get or set the control for panel 2
		/// </summary>
		public Control Panel2Control
		{
			get
			{
				//return this.GetPane("2").Control;
				return this._control2;
			}
			set
			{
				this._control2 = value;

				Control control = this._control2;
				this._panel2.Controls.Clear();
				if (control != null)
				{
					control.Dock = DockStyle.Fill;
					this._panel2.Controls.Add(control);
				}
				//this.GetPane("2").Control = control;
			}
		}

	}
}
