using System;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinTabControl;

namespace InfragisticsDockableTestApplication
{
    /// <summary>
    /// Defines cDataSection ITabContainer that also implements cDataSection UserControl and ITabController
    /// </summary>
    public partial class TabContainer : UserControl
    {
        #region private
        private bool _skipSelecteEvents;
        #endregion
        /// <summary>
        /// Default constructor
        /// </summary>
        public TabContainer()
        {
            InitializeComponent();
            this._skipSelecteEvents = false;
        }

        /// <summary>
        /// Add cDataSection tab page to this ITabContainer
        /// </summary>
        /// <param name="page">The page to be added</param>
        private void AddPage(Control page, string title, string key)
        {
            //See: http://help.infragistics.com/Help/NetAdvantage/WinForms/2011.1/CLR2.0/html/Infragistics2.Win.UltraWinTabControl.v11.1~Infragistics.Win.UltraWinTabControl.UltraTab.html


            // Call BeginUpdate to prevent the display from
            // refreshing as we add individual tabs.
            // Note: This MUST be paired with a call to
            // EndUpdate below.
            this.tabControl.BeginUpdate();

            // Specify that mnemonics will be supported. If so and
            // there is an '&' in a tab's text, the following character
            // will be treated as an accelerator (i.e. the tab will
            // be activated when the user presses the 'Alt' key and 
            // that character).
            this.tabControl.UseMnemonics = DefaultableBoolean.True;

            UltraTab tabAdded;
            UltraTabsCollection tabs = this.tabControl.Tabs;

            // Add a tab to the Tabs collection
            //tabAdded = tabs.Add("options", "&Options");
            tabAdded = tabs.Add(key, title);

            // Setting the FixedWidth property will cause
            // this tab to be displayed that size regardless
            // of what is required to display its image and
            // text
            //tabAdded.FixedWidth = 80; // pixels

            //// Create a new control
            //TextBox tb = new TextBox();
            //tb.Location = new Point(20, 20);
            //tb.Size = new Size(80, 20);

            //// Add the control to the tab's tab page
            //tabAdded.TabPage.Controls.Add(tb);
            tabAdded.TabPage.Controls.Add(page);
            page.Dock = DockStyle.Fill;

            //// Continue to add tabs
            //tabAdded = tabs.Add("general", "&General");
            //tabAdded = tabs.Add("advanced", "Ad&vanced");

            // Select the 'options' tab by setting the SelectedTab
            // property. This will raise the ActiveTabChanging,
            // ActiveTabChanged, SelectedTabChanging and 
            // SelectedTabChanged events. It will also cause
            // the 'options' tab TabPage to be made visible and
            // the tab to scroll into view.
            //this.tabControl.SelectedTab = tabs["options"];

            // Activate the 'general' tab by setting the ActiveTab
            // property. This will raise the ActiveTabChanging,
            // and ActiveTabChanged events. It will also cause
            // the tab to scroll into view but the only other
            // visible change will be that a focus rect will
            // be drawn around the tab if the control has focus. 
            //this.tabControl.ActiveTab = tabs["general"];

            // Give the tab control focus
            //this.tabControl.Focus();

            // Call EndUpdate to allow the display to refresh
            this.tabControl.EndUpdate();
        }

        private void TabContainer_Load(object sender, EventArgs e)
        {
            FakePage fakePage = new FakePage();
            this.AddPage(fakePage, "Fake", "Fake");

            //TabControlDockable tabControlDockable = new TabControlDockable();
            //this.AddPage(tabControlDockable, "Dockable", "Dockable");

            //this.selectTab("Fake");





            //MultiSplitContainerDockable multiSplitContainerDockable = new MultiSplitContainerDockable();
            //multiSplitContainerDockable.Dock = DockStyle.Fill;
            //multiSplitContainerDockable.TabText1 = "Chart";
            //multiSplitContainerDockable.TabText4 = "Time series data";
            //multiSplitContainerDockable.TabText2 = "Selected point";
            //multiSplitContainerDockable.TabText3 = "Quick watch";
            //this.AddPage(multiSplitContainerDockable, "Splittable", "Splittable");


            //UserControl control = new UserControl();
            //this.AddPage(control, "Splittable", "Splittable");
            //control.Dock = DockStyle.Fill;
            //MultiSplitContainerDockable multiSplitContainerDockable = new MultiSplitContainerDockable();
            //multiSplitContainerDockable.Dock = DockStyle.Fill;
            //multiSplitContainerDockable.TabText1 = "Chart";
            //multiSplitContainerDockable.TabText4 = "Time series data";
            //multiSplitContainerDockable.TabText2 = "Selected point";
            //multiSplitContainerDockable.TabText3 = "Quick watch";
            //control.Controls.Add(multiSplitContainerDockable);

            SeriesPage seriesPage = new SeriesPage();
            this.AddPage(seriesPage, "SeriesPage", "SeriesPage");
        }       
    }
}
