using System.Collections.Generic;
using System.Windows.Forms;

namespace InfragisticsDockableTestApplication
{
    /// <summary>
    /// Implement a TabControl with tab-dock, tab-move, tab-resize capabilities
    /// </summary>
    public partial class TabControlDockable :UserControl// TabControl
    {
        #region private
        private Infragistics.Win.UltraWinDock.DockableWindow dockableWindow;
        #endregion
        /// <summary>
        /// Default constructor
        /// </summary>
        public TabControlDockable()
        {
            InitializeComponent();
            this.ultraDockManager.DefaultPaneSettings.AllowClose = Infragistics.Win.DefaultableBoolean.False;

            // 
            // dockableWindow3
            // 
            this.dockableWindow = new Infragistics.Win.UltraWinDock.DockableWindow();
            dockableWindow.SuspendLayout();

            //dockableWindow.Controls.Add(c);
            dockableWindow.Name = "dockableWindow";
            dockableWindow.Owner = this.ultraDockManager;

            dockableWindow.ResumeLayout(false);

        }

        #region IChartControlContainer Members


        /// <summary>
        /// True if this control contains the specified key, false otherwise
        /// </summary>
        /// <param name="key">a key</param>
        /// <returns>True if this control contains the specified key, false otherwise</returns>
        public bool ContainsKey(string key)
        {
            foreach (string s in this.ControlKeys)
            {
                if (s == key)
                {
                    return true;
                }
            }
            return false;
        }

        /// <summary>
        /// Get the keys of the added controls
        /// </summary>
        public IEnumerable<string> ControlKeys
        {
            get
            {
                if (this.ultraDockManager.DockAreas.Count > 0)
                {
                    Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane = this.ultraDockManager.DockAreas[0];
                    foreach (Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane in dockAreaPane.Panes)
                    {
                        yield return dockableControlPane.Key;
                    }
                }
            }
        }

        /// <summary>
        /// Return the control with the specified key
        /// </summary>
        /// <param name="key">the key of the control to be retireved</param>
        /// <returns>the control with the specified key</returns>
        public Control this[string key]
        {
            get
            {
                Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane = this.ultraDockManager.DockAreas[0];
                Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane = dockAreaPane.Panes[key] as Infragistics.Win.UltraWinDock.DockableControlPane;
                return dockableControlPane.Control;
            }
        }

        /// <summary>
        /// Add a control
        /// </summary>
        /// <param name="control">The control to be added</param>
        /// <param name="key">The key that identifies the control</param>
        /// <param name="description">A description for the control</param>
        public void AddControl(Control control, string key, string description)
        {
            Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane;

            if (this.ultraDockManager.DockAreas.Count == 0)
            {
                dockAreaPane = new Infragistics.Win.UltraWinDock.DockAreaPane(Infragistics.Win.UltraWinDock.DockedLocation.DockedLeft);
                dockAreaPane.ChildPaneStyle = Infragistics.Win.UltraWinDock.ChildPaneStyle.TabGroup;
                this.ultraDockManager.DockAreas.AddRange(new Infragistics.Win.UltraWinDock.DockAreaPane[] { dockAreaPane });
            }
            else
            {
                dockAreaPane = this.ultraDockManager.DockAreas[0];
            }


            control.Dock = DockStyle.Fill;

            Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane = new Infragistics.Win.UltraWinDock.DockableControlPane(key, description, control);

            dockableControlPane.Control = control;
            dockableControlPane.Text = description;

            dockAreaPane.Panes.Add(dockableControlPane);

            this.ultraDockManager.DockAreas[0].SelectedTabIndex = this.ultraDockManager.DockAreas[0].Panes.Count;
        }

        /// <summary>
        /// Remove the control with the specified key
        /// </summary>
        /// <param name="key">The key that identifies the control</param>
        public void RemoveControl(string key)
        {
            if (this.ultraDockManager.DockAreas.Count > 0)
            {
                Infragistics.Win.UltraWinDock.DockAreaPane dockAreaPane = this.ultraDockManager.DockAreas[0];
                Infragistics.Win.UltraWinDock.DockableControlPane dockableControlPane = dockAreaPane.Panes[key] as Infragistics.Win.UltraWinDock.DockableControlPane;

                Control controlToBeRemoved = dockableControlPane.Control;

                dockAreaPane.Panes.Remove(dockableControlPane);

                this.ultraDockManager.ControlPanes.Remove(dockableControlPane);
                this.Controls.Remove(controlToBeRemoved);

                // this is maybe a bug of private Infragistics.Win.UltraWinDock.UltraDockManager:
                // at this point, infact:
                //  this.ultraDockManager.LayoutStyle == Infragistics.Win.UltraWinDock.DockAreaLayoutStyle.FillContainer
                // but the remaining panes are shown docked left.
                // we have to change the LayoutStyle to see the correct behaviour
                // (this bug arise when adding 2 tabs, then removing the 1st one.)
                this.ultraDockManager.LayoutStyle = Infragistics.Win.UltraWinDock.DockAreaLayoutStyle.Standard;
                this.ultraDockManager.LayoutStyle = Infragistics.Win.UltraWinDock.DockAreaLayoutStyle.FillContainer;
            }
        }

        #endregion
    }
}
